@@ -1,10 +1,10 @@
 package Dist::Zilla::Plugin::Alien;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Use Alien::Base with Dist::Zilla
-$Dist::Zilla::Plugin::Alien::VERSION = '0.022';
+$Dist::Zilla::Plugin::Alien::VERSION = '0.023';
 use Moose;
 extends 'Dist::Zilla::Plugin::ModuleBuild';
-with 'Dist::Zilla::Role::PrereqSource', 'Dist::Zilla::Role::FileGatherer';
+with 'Dist::Zilla::Role::PrereqSource', 'Dist::Zilla::Role::FileGatherer', 'Dist::Zilla::Role::MetaProvider';
 
 
 use URI;
@@ -103,6 +103,11 @@ has install_command => (
 	is => 'rw',
 );
 
+has test_command => (
+	isa => 'ArrayRef[Str]',
+	is => 'rw',
+);
+
 has isolate_dynamic => (
 	isa => 'Int',
 	is => 'rw',
@@ -148,6 +153,22 @@ sub _helper_hash {
 	\%helper;
 }
 
+has env => (
+	isa => 'ArrayRef[Str]',
+	is => 'rw',
+	default => sub { [] },
+);
+
+sub _env_hash {
+	my($self) = @_;
+	my %env = map {
+	  /^\s*(.*?)\s*=\s*(.*)\s*$/ 
+	    ? ($1 => $2) 
+	    : $self->log_fatal("Please specify a value for $_")
+	  } @{ $self->env };
+	\%env;
+}
+
 has stage_install => (
 	isa => 'Int',
 	is  => 'rw',
@@ -171,14 +192,13 @@ has version_check => (
 # multiple build/install commands return as an arrayref
 around mvp_multivalue_args => sub {
   my ($orig, $self) = @_;
-  return ($self->$orig, 'build_command', 'install_command', 'inline_auto_include', 'bin_requires', 'helper');
+  return ($self->$orig, 'build_command', 'install_command', 'test_command', 'inline_auto_include', 'bin_requires', 'helper', 'env');
 };
 
 sub register_prereqs {
 	my ( $self ) = @_;
 
 	my $ab_version = '0.002';
-	my $configure_requires = {};
 
 	if(defined $self->isolate_dynamic || defined $self->autoconf_with_pic || grep /(?<!\%)\%c/, @{ $self->build_command || [] }) {
 		$ab_version = '0.005';
@@ -186,19 +206,20 @@ sub register_prereqs {
 
 	if(@{ $self->inline_auto_include } || @{ $self->bin_requires } || defined $self->msys) {
 		$ab_version = '0.006';
-		if(@{ $self->bin_requires }) {
-			$configure_requires = $self->_bin_requires_hash;
-		}
 	}
 	
 	if(defined $self->stage_install) {
 		$ab_version = '0.016';
 	}
 	
-	if(@{ $self->helper } || grep /(?<!\%)\%\{([a-zA-Z_][a-zA-Z_0-9]+)\}/, @{ $self->build_command || [] }, @{ $self->install_command || [] } ) {
+	if(@{ $self->helper } || grep /(?<!\%)\%\{([a-zA-Z_][a-zA-Z_0-9]+)\}/, @{ $self->build_command || [] }, @{ $self->install_command || [] }, @{ $self->test_command || [] } ) {
 		$ab_version = '0.020';
 	}
 
+	if(@{ $self->env } || grep /(?<!\%)\%X/, @{ $self->build_command || [] }, @{ $self->install_command || [] }, @{ $self->test_command || [] } ) {
+		$ab_version = '0.027';
+	}
+
 	$self->zilla->register_prereqs({
 			type  => 'requires',
 			phase => 'configure',
@@ -206,7 +227,6 @@ sub register_prereqs {
 		'Alien::Base::ModuleBuild' => $ab_version,
 		'File::ShareDir' => '1.03',
 		@{ $self->split_bins } > 0 ? ('Path::Class' => '0.013') : (),
-		%$configure_requires,
 	);
 	$self->zilla->register_prereqs({
 			type  => 'requires',
@@ -269,6 +289,7 @@ around module_build_args => sub {
 
 	my $bin_requires = $self->_bin_requires_hash;
 	my $helper       = $self->_helper_hash;
+	my $env          = $self->_env_hash;
 
 	return {
 		%{ $self->$orig(@args) },
@@ -293,6 +314,7 @@ around module_build_args => sub {
 		},
 		(alien_build_commands => $self->build_command)x!! $self->build_command,
 		(alien_install_commands => $self->install_command)x!! $self->install_command,
+		(alien_test_commands => $self->test_command)x!! $self->test_command,
 		(alien_inline_auto_include => $self->inline_auto_include)x!! $self->inline_auto_include,
 		defined $self->autoconf_with_pic ? (alien_autoconf_with_pic => $self->autoconf_with_pic) : (),
 		defined $self->isolate_dynamic ? (alien_isolate_dynamic => $self->isolate_dynamic) : (),
@@ -303,9 +325,20 @@ around module_build_args => sub {
 		defined $self->provides_cflags ? (alien_provides_cflags => $self->provides_cflags) : (),
 		%$bin_requires ? ( alien_bin_requires => $bin_requires ) : (),
 		%$helper ? ( alien_helper => $helper ): (),
+		%$env ? ( alien_env => $env ) : (),
 	};
 };
 
+sub _is_dynamic_config {
+	my($self) = @_;
+	%{ $self->_bin_requires_hash } || $self->msys || @{ $self->build_command || [] } == 0 || grep /(?<!\%)\%c/, @{ $self->build_command || [] };
+}
+
+sub metadata {
+	my($self) = @_;
+	$self->_is_dynamic_config ? { dynamic_config => 1 } : {};
+}
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
@@ -320,7 +353,7 @@ Dist::Zilla::Plugin::Alien - Use Alien::Base with Dist::Zilla
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -417,6 +450,13 @@ C<alien_install_commands> option). This is optional.
 
   install_command = make install
 
+=head2 test_command
+
+The ordered sequence of commands used to test the distribution (passed to the
+C<alien_test_commands> option).  This is optional, and not often used.
+
+  test_command = make check
+
 =head2 isolate_dynamic
 
 If set to true, then dynamic libraries will be isolated from the static libraries
@@ -475,7 +515,7 @@ Defines helpers.  You can specify the content of the helper (which will be evalu
 in L<Alien::Base::ModuleBuild> during the build/install step) using the equal C<=> sign.
 
  [Alien]
- helper = mytool = 'mytool --foo --bar'
+ helper = mytool = '"mytool --foo --bar"'
 
 =head2 provides_cflags
 
@@ -489,6 +529,35 @@ Sets the C<alien_provides_libs> property for L<Alien::Base::ModuleBuild>.
 
 Sets the C<alien_version_check> property for L<Alien::Base::ModuleBuild>.
 
+=head2 env
+
+Sets the C<alien_env> property for L<Alien::Base::ModuleBuild>.  You can specify
+the content of the environment using the equal C<=> sign.  Note that values
+are interpolated, and allow variables and helpers.
+
+ [Alien]
+ helper = path = 'require Config;$Config{path_sep}$ENV{PATH}'
+ ; sets PATH to /extra/path:$PATH on UNIX, /extra/path;$PATH on Windows
+ env = PATH = /extra/path%{path}
+ ; sets FOO to 1
+ env = FOO = 1
+
+There is no default value, so this is illegal:
+
+ [Alien]
+ ; won't build!
+ env = FOO
+
+Note that setting an environment variable to the empty string (C<''>) is not
+portable.  In particular it will work on Unix as you might expect, but in
+Windows it will actually unset the environment variable, which may not be
+what you intend.
+
+ [Alien]
+ ; works but not consistent
+ ; over all platforms
+ env = FOO =
+
 =head1 InstallRelease
 
 The method L<Alien::Base> is using would compile the complete Alien 2 times, if
