@@ -1,14 +1,20 @@
 package Dist::Zilla::PluginBundle::Alien;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Dist::Zilla::PluginBundle::Basic for Alien
-$Dist::Zilla::PluginBundle::Alien::VERSION = '0.022';
+$Dist::Zilla::PluginBundle::Alien::VERSION = '0.023';
 use Moose;
 use Dist::Zilla;
+use Dist::Zilla::Plugin::Alien;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 
 use Dist::Zilla::PluginBundle::Basic;
 
+# multiple build/install commands return as an arrayref
+sub mvp_multivalue_args {
+  Dist::Zilla::Plugin::Alien->mvp_multivalue_args;
+};
+
 sub configure {
   my ($self) = @_;
 
@@ -36,7 +42,7 @@ Dist::Zilla::PluginBundle::Alien - Dist::Zilla::PluginBundle::Basic for Alien
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
